@@ -4,7 +4,7 @@ import uvicorn
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 
-from lndb_rest_instance.routers import metadata
+from lndb_rest_instance.routers import introspection, metadata
 
 root_path = "/" + os.getenv("ROOT_PATH", "")
 
@@ -19,7 +19,8 @@ app.add_middleware(
 )
 
 app.include_router(metadata.router)
+app.include_router(introspection.router)
 
 
 if __name__ == "__main__":
-    uvicorn.run(app, host="0.0.0.0", port=8000, root_path=root_path)
+    uvicorn.run("main:app", host="0.0.0.0", port=8000, root_path=root_path)
